==> docusign-esign-java-2.1.0-sources.jar: com/docusign/esign/model/BrandLink.java <==
package com.docusign.esign.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonValue;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;





@javax.annotation.Generated(value = "class io.swagger.codegen.languages.JavaClientCodegen", date = "2017-03-06T16:42:36.211-08:00")
public class BrandLink   {
  
  private String linkText = null;
  private String linkType = null;
  private String showLink = null;
  private String urlOrMailTo = null;

  
  /**
   * 
   **/
  
  @ApiModelProperty(value = "")
  @JsonProperty("linkText")
  public String getLinkText() {
    return linkText;
  }
  public void setLinkText(String linkText) {
    this.linkText = linkText;
  }

  
  /**
   * 
   **/
  
  @ApiModelProperty(value = "")
  @JsonProperty("linkType")
  public String getLinkType() {
    return linkType;
  }
  public void setLinkType(String linkType) {
    this.linkType = linkType;
  }

  
  /**
   * 
   **/
  
  @ApiModelProperty(value = "")
  @JsonProperty("showLink")
  public String getShowLink() {
    return showLink;
  }
  public void setShowLink(String showLink) {
    this.showLink = showLink;
  }

  
  /**
   * 
   **/
  
  @ApiModelProperty(value = "")
  @JsonProperty("urlOrMailTo")
  public String getUrlOrMailTo() {
    return urlOrMailTo;
  }
  public void setUrlOrMailTo(String urlOrMailTo) {
    this.urlOrMailTo = urlOrMailTo;
  }

  

  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BrandLink brandLink = (BrandLink) o;

    return true && Objects.equals(linkText, brandLink.linkText) &&
        Objects.equals(linkType, brandLink.linkType) &&
        Objects.equals(showLink, brandLink.showLink) &&
        Objects.equals(urlOrMailTo, brandLink.urlOrMailTo)
    ;
  }

  @Override
  public int hashCode() {
    return Objects.hash(linkText, linkType, showLink, urlOrMailTo);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class BrandLink {\n");
    
    if (linkText != null)
      sb.append("    linkText: ").append(toIndentedString(linkText)).append("\n");
    if (linkType != null)
      sb.append("    linkType: ").append(toIndentedString(linkType)).append("\n");
    if (showLink != null)
      sb.append("    showLink: ").append(toIndentedString(showLink)).append("\n");
    if (urlOrMailTo != null)
      sb.append("    urlOrMailTo: ").append(toIndentedString(urlOrMailTo)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> docusign-esign-java-3.18.0-sources.jar: com/docusign/esign/model/BrandLink.java <==
package com.docusign.esign.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * BrandLink.
 *
 */

public class BrandLink {
  @JsonProperty("linkText")
  private String linkText = null;

  @JsonProperty("linkType")
  private String linkType = null;

  @JsonProperty("showLink")
  private String showLink = null;

  @JsonProperty("urlOrMailTo")
  private String urlOrMailTo = null;


  /**
   * linkText.
   *
   * @return BrandLink
   **/
  public BrandLink linkText(String linkText) {
    this.linkText = linkText;
    return this;
  }

  /**
   * .
   * @return linkText
   **/
  @ApiModelProperty(value = "")
  public String getLinkText() {
    return linkText;
  }

  /**
   * setLinkText.
   **/
  public void setLinkText(String linkText) {
    this.linkText = linkText;
  }


  /**
   * linkType.
   *
   * @return BrandLink
   **/
  public BrandLink linkType(String linkType) {
    this.linkType = linkType;
    return this;
  }

  /**
   * .
   * @return linkType
   **/
  @ApiModelProperty(value = "")
  public String getLinkType() {
    return linkType;
  }

  /**
   * setLinkType.
   **/
  public void setLinkType(String linkType) {
    this.linkType = linkType;
  }


  /**
   * showLink.
   *
   * @return BrandLink
   **/
  public BrandLink showLink(String showLink) {
    this.showLink = showLink;
    return this;
  }

  /**
   * .
   * @return showLink
   **/
  @ApiModelProperty(value = "")
  public String getShowLink() {
    return showLink;
  }

  /**
   * setShowLink.
   **/
  public void setShowLink(String showLink) {
    this.showLink = showLink;
  }


  /**
   * urlOrMailTo.
   *
   * @return BrandLink
   **/
  public BrandLink urlOrMailTo(String urlOrMailTo) {
    this.urlOrMailTo = urlOrMailTo;
    return this;
  }

  /**
   * .
   * @return urlOrMailTo
   **/
  @ApiModelProperty(value = "")
  public String getUrlOrMailTo() {
    return urlOrMailTo;
  }

  /**
   * setUrlOrMailTo.
   **/
  public void setUrlOrMailTo(String urlOrMailTo) {
    this.urlOrMailTo = urlOrMailTo;
  }


  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BrandLink brandLink = (BrandLink) o;
    return Objects.equals(this.linkText, brandLink.linkText) &&
        Objects.equals(this.linkType, brandLink.linkType) &&
        Objects.equals(this.showLink, brandLink.showLink) &&
        Objects.equals(this.urlOrMailTo, brandLink.urlOrMailTo);
  }

  /**
   * Returns the HashCode.
   */
  @Override
  public int hashCode() {
    return Objects.hash(linkText, linkType, showLink, urlOrMailTo);
  }


  /**
   * Converts the given object to string.
   */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class BrandLink {\n");
    
    sb.append("    linkText: ").append(toIndentedString(linkText)).append("\n");
    sb.append("    linkType: ").append(toIndentedString(linkType)).append("\n");
    sb.append("    showLink: ").append(toIndentedString(showLink)).append("\n");
    sb.append("    urlOrMailTo: ").append(toIndentedString(urlOrMailTo)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
